#!/usr/bin/env bash
# File Name: scamp.sh
# Purpose: Download and install third party Clamav definition files.
# Version: 5.2c
# Date: Tue, 19 May 2009 16:58:25 GMT
# Author: Gerard Seibert <gerard@seibercom.net>

## ************************ DECLARE STATEMENTS *******************************##
# Declare statements - Should not be altered !
declare -a DIRLIST
declare -a MSRBL_LIST
declare -a ZIPFILES
declare -i CREATE_CONFIG
declare -i DIRLIST_COUNT
declare -i EDIT_CONFIG
declare -i FAILED
declare -i GET_LDB
declare -i GET_MALWARE
declare -i GET_MSRBL
declare -i GET_SANE
declare -i GET_SECURITE
declare -i GET_WINNOW
declare -i INSTALLED
declare -i IS_DIGIT
declare -i LIMIT
declare -i L_TYPE
declare -i MK_LOG
declare -i MSRBL_COUNT
declare -i NO_UPDATE
declare -i RELOAD
declare -i REST
declare -i RESTING
declare -i SYS_LOG
declare -i WPC
declare -i W_SUM
declare -i ZIPFILES_COUNT

## ************************************************************************** ##
: << DEFAULTS
These are the default values for the program. They can be over written by
1) using the [-c] option and creating a new config file
DEFAULTS

SCRIPT_NAME="scamp"
VERSION="5.2c"

# You can set the location of the Clamav database here using the $SIG_DB
# variable or you can set it using an environmental variable.
# By default, it is NULL -- you must set it in the config file. The config
# file setting will OVER-RIDE the setting here or in the environment.
# Place the exact PATH between the double quotation marks.

SIG_DB=$SIG_DB:-"/var/db/clamav"}

CONFIG_DIR=${CONFIG_DIR:-"/etc/scamp"}
CONFIG_FILE=${CONFIG_FILE:-${CONFIG_DIR}/default}
C_GROUP=${C_GROUP:-"clamav"}
C_PID=${C_PID:-"/var/run/clamav/clamd.pid"}
C_USER=${C_USER:-"clamav"}
GET_LDB=${GET_LDB:-1}
GET_MALWARE=${GET_MALWARE:-1}
GET_MSRBL=${GET_MSRBL:-1}
GET_SANE=${GET_SANE:-1}
GET_SECURITE=${GET_SECURITE:-1}
GET_WINNOW=${GET_WINNOW:-1}
L_TYPE=${L_TYPE:-1}
MK_LOG=${MK_LOG:-0}
RELOAD=${RELOAD:-1}
REST=${REST:-0}
SYS_LOG=${SYS_LOG:-1}
WPC=${WPC:-0}
W_SUM=${W_SUM:-1}

# Check to see if the config directory exists
if ! [[ -d ${CONFIG_DIR} ]]; then
  mkdir -p -m 0755 ${CONFIG_DIR}
fi
## ************************************************************************** ##
function readconf()
{
while read line; do
# skip comments
  [[ ${line:0:1} == "#" ]] && continue
# skip empty lines
  [[ -z "${line}" ]] && continue
  eval ${line}
done < "${CONFIG_FILE}"
}
## ************************************************************************** ##
<< ASSIGN-FUNCTION
This simple function takes the preset value of a variable and compares it with
the value imput by the user. If it is a new value, the old value is over written
and the new value is placed in the 'config file'.
ASSIGN-FUNCTION

# This function assigns the user input to the correct variables
function assign_value ()
{
# Check to see how many variables were passed
# See if two were passed
if [[ ${#} -eq 2 ]]; then
  eval ${2}=\${1}
fi
}
: << ReadInput
We are going to get the values for the variables to be placed in the 'config' file.
ReadInput
## ************************************************************************** ##
# Check input
test_char ()
{
IS_DIGIT=0

# Call function 'null_char'
case "$1" in
  [[:digit:]] )
    IS_DIGIT=1
  ;;
  * )
    IS_DIGIT=0
printf "\n\a\t   *****WARNING*****
\tYou must enter a digit\n\n"
  ;;
esac
}
## ************************************************************************** ##
# Check for null character
function null_char () {
num=${1}
if [[ -z ${num} ]]; then
  break
else
  test_char ${num}
fi
}
## ************************************************************************** ##
function make_config ()
{
printf "\f"
if [[ ${1} ]]; then
  CONFIG_FILE=${1}
fi

while [[ ! ${sig_db} ]]; do
  printf "\f"
    if [[ -n ${ER_1} ]]; then
      printf "${ER_1}\n\n"
    fi
  printf "Enter the location of the Clamav Database. It must be a Fully Qualified
path. Check your documentation. If it is entered incorrectly, the script will
fail. Usually locations:\n
/var/db/clamav
/var/lib/clamav
/usr/local/share/clamav\n
You MUST enter a PATH!\n\n
Press <RETURN> to accept default -- or modify if required
Clamav Database location:\n\n"
  if [[ -z ${SIG_DB} ]]; then
    printf "[NO DEFAULT SETTING] "
    read sig_db
    assign_value ${sig_db} SIG_DB
  else
    printf "[Default: %s ] " ${SIG_DB}
    read sig_db
    assign_value ${sig_db} SIG_DB
    break
  fi
done

printf "\f"

# Get the rest of the needed config file variables.
printf "\nAll settings may be set to DEFAULT by pressing <RETURN> at each option.\n"

# Set the tmp directory if it doesn't exist
if [[ -z ${T_DIR} ]]; then
  T_DIR="${SIG_DB}/tmp"
fi
printf "\n\nYou may set the temp directory to be used by this script here.\n\n"
printf "Enter the Fully Qualified PATH here.\n
[Default = %s ] " ${T_DIR}
read t_dir
assign_value ${t_dir} T_DIR
printf "\f"

printf "\n\nCheck the 'PidFile' setting in your clamd.conf file
for the location of the Clamd PID file\n\n
Enter the fully qualified file name of the PID file:\n
[Default: %s ] " ${C_PID}
read c_pid
assign_value ${c_pid} C_PID
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
printf "\n\n\nDo you want to turn on the random download timer?
It only works when run via CRON. 1=on & 0=off\n
[default: %d ] " ${REST}
read rest
null_char ${rest}
done
assign_value ${rest} REST
printf "\f"

printf "\n\n\nEnter: GROUP ownership of files:\n
[default: %s ] " ${C_GROUP}
read c_group
assign_value ${c_group} C_GROUP
printf "\f"

printf "\n\n\nEnter: USER ownership of files:\n
[default: %s ] " ${C_USER}
read c_user
assign_value ${c_user} C_USER
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
printf "\n\n\nInstall the Sanesecurity files: 1=yes & 0=no\n
[default = %d ] " ${GET_SANE}
read get_sane
null_char ${get_sane}
done
assign_value ${get_sane} GET_SANE

if [[ ${GET_SANE} -eq 1 ]]; then
IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
printf "\n\n\nThe Sanesecurity *.ldb files only work with Clamav >=0.94
DO NOT download if you have an older version of Clamav installed.
See http://vrt-sourcefire.blogspot.com/2008/09/logical-signatures-in-clamav-094.html for further details.\n\n"
printf "\nInstall the Sanesecurity *.ldb files: 1=yes & 0=no\n
[Default = %d ] " ${GET_LDB}
read get_ldb
null_char ${get_ldb}
done
assign_value ${get_ldb} GET_LDB
else
GET_LDB=0
WPC=0
GET_WINNOW=0
fi
printf "\f"

if [[ ${GET_SANE} -eq 1 ]]; then
  IS_DIGIT=0
  while [[ ${IS_DIGIT} -eq 0 ]]; do
    printf "\f\n\nInstall the Winnow files?\n
Please see: http://winnow.oitc.com/clamsigs/index.html for full details.\n\n"
    printf "1=yes & 0=no\n
[Default = %d ] " ${GET_WINNOW}
    read get_winnow
    null_char ${get_winnow}
  done
assign_value ${get_winnow} GET_WINNOW
printf "\f"
  if [[ ${GET_WINNOW} -eq 1 ]]; then
    ans=0
      while [[ ${ans} -eq 0 ]]; do
        IS_DIGIT=0
        while [[ ${IS_DIGIT} -eq 0 ]]; do
printf "\nwinnow files provided are:

winnow_malware.hdb - Current virus, trojan and other malware
not yet detected by ClamAV

winnow_malware_links.ndb - Signatures to detect links to malware
in winnow_malware.hdb and links to other malicious malware.
(Scoring is not required on these signatures)

winnow_phish_complete.ndb - Signatures to detect phishing and other
malicious url's and compromised hosts. This collection of signatures
are derived by checking many data feeds (see below) coupled with
special processing to remove the possibility of false positives.
(Recommended to be used with scoring)

winnow_phish_complete_url.ndb - Similar to winnow_phish_complete.ndb
except that entire urls's are used to derive the signatures rather than
carefully selected hosts. (Conservative) Be advised that by using
these complete url signatures, fast flux phishing sites as well as
phishing sites that use obfuscated urls and those that insert trash
in urls to confuse anti-malware systems may not be reliably detected
by some of these signatures (Conservative and can be used without scoring).

winnow_spam_complete.ndb - Signatures to detect fraud and other malicious
spam. This collection of signatures are derived using special processing
on data sent to spam traps and honeypots.
(Scoring of these signatures is recommended)

(1) = Install the non-scoring files only
(2) = Install the scoring recommended files only
(3) = Install all winnow files

[Default = %d ] " ${WPC}
read wpc
null_char ${wpc}
        done
  assign_value ${wpc} WPC
  if [[ ${WPC} -gt 3 || ${WPC} -lt 1 ]]; then
    unset WPC
    printf "\tYou must enter either 1, 2 or 3\n"
    printf "\tPress any key to continue. "
    read x
    printf "\f"
  else
    ans=1
  fi
      done
  fi
fi
printf "\f"
IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nInstall the MSRBL files: 1=yes & 0=no\n
[default = %d ] " ${GET_MSRBL}
  read get_msrbl
  null_char ${get_msrbl}
done
assign_value ${get_msrbl} GET_MSRBL
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nInstall the Malware files: 1=yes & 0=no\n
[default = %d ] " ${GET_MALWARE}
  read get_malware
  null_char ${get_malware}
done
assign_value ${get_malware} GET_MALWARE
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nInstall the Securiteinfo files: 1=yes & 0=no\n
[default = %d ] " ${GET_SECURITE}
  read get_securite
  null_char ${get_securite}
done
assign_value ${get_securite} GET_SECURITE
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nReload clamd after update: 1=yes & 0=no\n
[default = %d ] " ${RELOAD}
  read reload
  null_char ${reload}
done
assign_value ${reload} RELOAD
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nDo you want a summary screen printed out when finished?
Enter 1 to display the screen or 0 to skip it.\n
[Default = %d ] " ${W_SUM}
  read w_sum
  null_char ${w_sum}
done
assign_value ${w_sum} W_SUM
printf "\f"

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nDo you want to create a log file?
Default Location: /var/log/scamp.log\n
Enter 1 for yes & 0 for no.\n
[Default = %d ] " ${MK_LOG}
  read mk_log
  null_char ${mk_log}
done
assign_value ${mk_log} MK_LOG
printf "\f"

if [[ ${MK_LOG} -eq 1 ]]; then
IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nThe basic log file is named scamp.log in the /var/log directory.\n"
  printf "Do you want to use that name or one that is incremented each month?\n\n"
  printf "EXAMPLE: scamp-09-03.log (log for March 2009)\n\n"
  printf "Enter 0 for 'scamp.log' & 1 for 'scamp<date>.log'\n
[Default = %d ] " ${L_TYPE}
  read l_type
  null_char ${l_type}
done
assign_value ${l_type} L_TYPE
printf "\f"
fi

IS_DIGIT=0
while [[ ${IS_DIGIT} -eq 0 ]]; do
  printf "\n\n\nScamp can also log to the system logger.\n"
  printf "Would you like to enable this feature?\n\n"
  printf "\n0 = off & 1 = on\n
[Default = %d ] " ${SYS_LOG}
  read sys_log
  null_char ${sys_log}
done
assign_value ${sys_log} SYS_LOG
printf "\f"

  printf "\n\n\nDo you want to set the GNUPGHOME environment variable?\n"
  printf "Read man gpg2 for further information\n\n"
  printf "If in doubt, leave blank; i.e., just hit <RETURN>\n"
  printf "Enter PATH or <RETURN> to unset it.\n
[Default = %s ] " ${GNUPGHOME}
read gnupghome_var
  if [[ -n $gnupghome_var ]]; then
    assign_value ${gnupghome_var} GNUPGHOME_VAR
  fi
printf "\f"

# Print out a completion message
printf "\n\n\n
\tPlease Wait\n
\tWe are now configuring the system and installing the files\n"

: << Write-Config
This is where we actually write the configuration file. It should only be done
once or when there is a change in the configuration file.
Write-Config

if [[ ${EDIT_CONFIG} -eq 0 ]]; then
  touch ${CONFIG_FILE}
  printf "# This is the ${CONFIG_FILE} file.\n" >> ${CONFIG_FILE}
  printf "# Created %s %s %s %s %s\n\n" $(date "+%B %d, %Y @ %T") >> ${CONFIG_FILE}
elif [[ ${EDIT_CONFIG} -eq 1 ]]; then
  printf "\n\tInstall the new ${CONFIG_FILE} - Y or y to install: "
  unset ans
  read ans
  if [ "${ans}" == "y" -o "${ans}" == "Y" ]; then
    rm -f ${CONFIG_FILE}
  else
    printf "\n\tRetaining old ${CONFIG_FILE}\n"
    printf "\n\tExiting Program\n"
    exit 0
  fi
fi
# Location of the main Clamav data base
echo SIG_DB=${SIG_DB} >> ${CONFIG_FILE}

# Sets the tmp directory
echo T_DIR=${T_DIR} >> ${CONFIG_FILE}

# Set the Clamav group owner
echo C_GROUP=${C_GROUP} >> ${CONFIG_FILE}

# Set the location for the 'clamd.pid' file
echo C_PID=${C_PID} >> ${CONFIG_FILE}

# Set the user
echo C_USER=${C_USER} >> ${CONFIG_FILE}

# Whether to download the *.ldb files - 1 means yes and 0 means no
echo GET_LDB=${GET_LDB} >> ${CONFIG_FILE}

# Get Malware files - 1 means yes
echo GET_MALWARE=${GET_MALWARE} >> ${CONFIG_FILE}

# Get the MSRBL files - 1 means yes
echo GET_MSRBL=${GET_MSRBL} >> ${CONFIG_FILE}

# Get the sanesecurity files - 1 means yes
echo GET_SANE=${GET_SANE} >> ${CONFIG_FILE}

# Get the securiteinfo files - 1 means yes
echo GET_SECURITE=${GET_SECURITE} >> ${CONFIG_FILE}

# Get winnow files
echo GET_WINNOW=${GET_WINNOW} >> ${CONFIG_FILE}

# Save the GNUPGHOME environment variable if entered
  if [[ -n ${GNUPGHOME_VAR} ]]; then
    echo GNUPGHOME_VAR=${GNUPGHOME_VAR} >> ${CONFIG_FILE}
  fi

# Location of the sanesecurity key
echo gpg_key_url="http://www.sanesecurity.net/publickey.gpg" >> ${CONFIG_FILE}

# Save the log file type
echo L_TYPE=${L_TYPE} >> ${CONFIG_FILE}

# Whether to create a log file
echo MK_LOG=${MK_LOG} >> ${CONFIG_FILE}

# MSRBL URL
echo MSRBL="rsync://rsync.mirror.msrbl.com/msrbl/" >> ${CONFIG_FILE}

# These are the individual MSRBL files
echo msrbl_Images='MSRBL-Images.hdb' >> ${CONFIG_FILE}
echo msrbl_SPAM='MSRBL-SPAM.ndb' >> ${CONFIG_FILE}
echo msrbl_SPAM_CR='MSRBL-SPAM-CR.ndb' >> ${CONFIG_FILE}

# Sets the msrbl directory
echo MSR_DIR="${T_DIR}/msr" >> ${CONFIG_FILE}

# Set the Malware dir
echo MW_DIR="${T_DIR}/malware" >> ${CONFIG_FILE}

# Malware file name
echo MW_FILE="mbl.ndb" >> ${CONFIG_FILE}

# Malware URL
echo MW_URL="http://www.malwarepatrol.com.br/cgi/submit?action=list_clamav_ext" >> ${CONFIG_FILE}

# Whether to reload clamd if new files are installed - NO to stop
echo RELOAD=${RELOAD} >> ${CONFIG_FILE}

# Set the random download function - 0=off & 1=on
echo REST=${REST} >> ${CONFIG_FILE}

# Sanesecurity URL
echo SANE="rsync://rsync.sanesecurity.net/sanesecurity" >> ${CONFIG_FILE}

# Sanesecurity tmp directory
echo SANE_DB="${T_DIR}/sane" >> ${CONFIG_FILE}

# Set the Securiteinfo dir
echo SI_DIR="${T_DIR}/securite" >> ${CONFIG_FILE}

# The following are the individual securiteinfo files
echo SI_URL1="http://clamav.securiteinfo.com/vx.hdb.gz" >> ${CONFIG_FILE}
echo SI_URL2="http://clamav.securiteinfo.com/honeynet.hdb.gz" >> ${CONFIG_FILE}
echo SI_URL3="http://clamav.securiteinfo.com/securiteinfo.hdb.gz" >> ${CONFIG_FILE}
echo SI_URL4="http://clamav.securiteinfo.com/antispam.ndb.gz" >> ${CONFIG_FILE}

# These are the combined securiteinfo files in one variable
echo SI_URL='$SI_URL1" "$SI_URL2" "$SI_URL3" "$SI_URL4' >> ${CONFIG_FILE}

# Save the sys-log setting
echo SYS_LOG=${SYS_LOG} >> ${CONFIG_FILE}

# Which winnow file
echo WPC=${WPC} >> ${CONFIG_FILE}

# Whether to display the summary screen
echo W_SUM=${W_SUM} >> ${CONFIG_FILE}

chmod 0664 ${CONFIG_FILE}

# We now exit since a new config file has been installed
printf "\n\tCongratulations, you may now run the program normally\n"
exit
}

## ************************************************************************** ##

if [[ -s ${CONFIG_FILE} ]]; then
  readconf
else
  if [[ ! -t 0 ]]; then
    printf "\tYou cannot use this function via CRON.\n"
    printf "\tWe have to exit. Try again from the console\n"
    exit
  fi
  make_config ${CONFIG_FILE}
fi
## ************************************************************************** ##
# Get any command line options
while getopts "cC:e:hlLqQrRv" Option
do
case $Option in
h)
  printf "\f
USAGE: $0 [ [-c|-C <name>] [-e <name>] [-h|-v] [-l|-L] [-q|-Q] [-r|-R] ]\n
\t(-c) to create a new default config file
\t     delete old file & exit after completion\n
\t(-C <name>) to create an new config file\n
\t(-h) to view this help message\n
\t(-e) <name>) edit an existing config file\n
\t(-l) (lower case ell) to turn off logging\n
\t(-L) to activate logging\n
\t(-q) to skip printing the summary screen\n
\t(-Q) to display a summary screen\n
\t(-r) to deactivate the random download timing feature\n
\t(-R) to activate the random download feature\n
\t(-v) to view the script version and exit\n"
  exit 0
;;
# Turn the logging function off.
l)
  MK_LOG=0
;;
# Turn the logging function on.
L)
  MK_LOG=1
;;
# Turns on the random download timer. Works only via CRON
R)
  REST=1
  ;;
v)
  printf "\n\n\tVersion: %s\n\n" ${VERSION}
exit 0
;;
# Turn random timer off
r)
  REST=0
;;
# Turn summary output off
q)
  W_SUM=0
;;
# Turn summary output on
Q)
  W_SUM=1
;;
c)
if [[ ! -t 0 ]]; then
  printf "\tYou cannot use this function via CRON.\n"
  printf "\tWe have to exit. Try again from the console\n"
  exit
fi
printf "\f"
printf "\n\tAre you sure you want to erase your existing config file?\n"
printf "\n\tYou will be given the opportunity to create a new one.\n\n"
printf "\tAnswer [y|Y] to continue, anything else to exit. "
read answer
if [[ ${answer} == "y" || ${answer} == "Y" ]]; then
  if [[ -e ${CONFIG_FILE} ]]; then
    readconf
    rm ${CONFIG_FILE}
    make_config ${CONFIG_DIR}/default
  fi
else
  printf "\n\tEXITING PROGRAM\n"
  exit
fi
;;
C)
if [[ ${OPTARG:0:1} == "-" ]]; then
  printf "\n\tYou must enter a valid <name>\n\n"
  printf "\tEXAMPLE: ${0} -<option> <name>\n\n"
  printf "\tWe have to exit -- Sorry\n"
  exit
fi

CONFIG_FILE=${CONFIG_DIR}/${OPTARG}
if [[ -e ${CONFIG_FILE} ]]; then
  readconf
  break
fi
if [[ ! -e ${CONFIG_FILE} ]]; then
  if [[ ! -t 0 ]]; then
    printf "\tYou cannot use this function via CRON.\n"
    printf "\tWe have to exit. Try again from the console\n"
    exit
  fi
  printf "\f"
  printf "\n\tNo match found for %s\n" ${CONFIG_FILE}
  printf "\tWe will now procede to create the new config file.\n"
  printf "\n\tPress [X|x] to exit or any other key to continue: "
  read ANSWER
  if [[ ${ANSWER} = "x" || ${ANSWER} = "X" ]]; then
    printf "\n\tBye\n"
    exit
  else
    make_config ${CONFIG_FILE}
  fi
fi
;;
e)
if [[ ${OPTARG:0:1} == "-" ]]; then
  printf "\n\tYou must enter a valid <name>\n\n"
  printf "\tEXAMPLE: ${0} -<option> <name>\n\n"
  printf "\tWe have to exit -- Sorry\n"
  exit
fi
#
if [[ ! -t 0 ]]; then
  printf "\tYou cannot use this function via CRON.\n"
  printf "\tWe have to exit. Try again from the console\n"
  exit
fi
#
if [[ -z ${OPTARG} ]]; then
  printf "\n\tYou must enter a file to edit\n"
  printf "\t$0 -e <filename>\n\n"
  printf "\tExiting program - Please try again\n"
  exit
fi
#
CONFIG_FILE="${CONFIG_DIR}/${OPTARG}"
if [[ ! -e ${CONFIG_FILE} ]]; then
  printf "\n\t%s does not exist\n" ${CONFIG_FILE}
  printf "\n\tEnter [y or Y] to create, or <RETURN> to exit. "
  unset ans
  read ans
  if [[ ${ans} == "y" || ${ans} == "Y" ]]; then
    printf "Creating the ${CONFIG_FILE}\n"
    EDIT_CONFIG=0
    make_config ${CONFIG_FILE}
  else
    printf "Exiting the program\n"
    exit
  fi
else
# Edit the config file.
  EDIT_CONFIG=1
  readconf
  make_config ${CONFIG_FILE}
fi
;;
#
*)
  printf "\nIncorrect flag - Enter $0 -h to view help menu.\n"
  exit 1
;;
esac
done
shift $(($OPTIND - 1))
# Set the GNUPGHOME  variable if it is available
if [[ -n ${GNUPGHOME_VAR} ]]; then
export GNUPGHOME=${GNUPGHOME_VAR}
fi

## Other Global variables:
# GPG options
# check to see it the ~/.gnupg directory exists
if [[ -d ~/.gnupg ]]; then
  GPG_OPT="--no-options -q --no-default-keyring --keyring ${SANE_DB}/pubring.gpg"
else
  GPG_OPT="-q --no-default-keyring --keyring ${SANE_DB}/pubring.gpg"
fi
# Remove unneeded files
for d in sane msrbl securite malware
  do
    case "${d}" in
      sane)
        if [[ ${GET_SANE} -eq 0 ]]; then
          if [[ -d ${SANE_DB} ]]; then
            cd ${SANE_DB}
            for i in $(ls *.ndb *.hdb *.ftm *.ldb *.sig 2>/dev/null); do
              rm -f ${i}
                if [[ -d ${SIG_DB} ]]; then
              		rm -f ${SIG_DB}/${i}
								fi
            done
          elif [[ ${GET_LDB} -eq 0 ]]; then
            cd ${SANE_DB}
            for s in $(ls *.ldb *.ldb.sig 2>/dev/null); do
            rm -f ${s}
              if [[ -d ${SIG_DB} ]]; then
            		rm -f ${SIG_DB}/${s}
							fi
						done
          fi
        fi
        if [[ ${GET_WINNOW} -eq 0 ]]; then
          if [[ -d ${SANE_DB} ]]; then
            cd ${SANE_DB}
            for w in $(ls winnow* 2>/dev/null); do
              rm -f ${w}
                if [[ -d ${SIG_DB} ]]; then
              		rm -f ${SIG_DB}/${w}
								fi
						done
          fi
        elif [[ ${GET_WINNOW} -eq 1 && ${WPC} -eq 1 ]]; then
          if [[ -d ${SANE_DB} ]]; then
            cd ${SANE_DB}
            for w in $(ls winnow_phish_complete.ndb winnow_spam_complete.ndb 2>/dev/null); do
              rm -f ${w}
                if [[ -d ${SIG_DB} ]]; then
              		rm -f ${SIG_DB}/${w}
								fi
            done
          fi
        elif [[ ${GET_WINNOW} -eq 1 && ${WPC} -eq 2 ]]; then
          if [[ -d ${SANE_DB} ]]; then
            cd ${SANE_DB}
            for w in $(ls winnow_malware.hdb winnow_phish_complete_url.ndb winnow_malware_links.ndb 2>/dev/null); do
             rm -f ${w}
              if [[ -d ${SIG_DB} ]]; then
             		rm -f ${SIG_DB}/${w}
             	fi
            done
          fi
        fi
    ;;
      msrbl)
        if [[ ${GET_MSRBL} -eq 0 ]]; then
          if [[ -d ${MSR_DIR} ]]; then
            cd ${MSR_DIR}
             for m in $(ls MSRBL* 2>/dev/null); do
              rm -f ${m}
                if [[ -d ${SIG_DB} ]]; then
              		rm -f ${SIG_DB}/${m}
              	fi
          done
          fi
        fi
    ;;
    securite)
      if [[ ${GET_SECURITE} -eq 0 ]]; then
        if [[ -d ${SI_DIR} ]]; then
         cd ${SI_DIR}
          for j in $(ls *.gz 2>/dev/null); do
            rm -f ${j}
          done
          if [[ -d {SIG_DB} ]]; then
	          cd ${SIG_DB}
	          for i in $(ls antispam.ndb honeynet.hdb securiteinfo.hdb vx.hdb 2>/dev/null); do
	            rm -f ${SIG_DB}/${i}
	          done
	        fi
        fi
      fi
      ;;
      malware)
        if [[ ${GET_MALWARE} -eq 0 ]]; then
          if [[ -d ${SIG_DB} ]]; then
            cd ${SIG_DB}
            for mw in $(ls mbl.ndb 2>/dev/null); do
             rm -f ${mw}
            done
          fi
          if [[ -d ${MW_DIR} ]]; then
            cd ${MW_DIR}
              for i in $(ls * 2>/dev/null); do
                rm -f ${i}
              done
          fi
        fi
    ;;
    esac
  done
## ************************************************************************** ##
# Exit the program if the $SIG_DB setting not set.
if ! [[ ${SIG_DB} ]]; then
# Not set so exit program.
  printf "You must set the SIG_DB variable '(location of the Clamav database)'
for this script to work.
Aborting program ...\n"
  exit 2
fi

export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin
# For tcsh or csh shells you may need to use this instead. Comment out above
# and uncomment this. Modify as required.
# set PATH = (/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin)
## ************************************************************************** ##
# Make sure the directory exist. Create if not.

for D in ${T_DIR} ${SANE_DB} ${MSR_DIR} ${SI_DIR} ${MW_DIR}
  do
    if [[ ! -d ${D} ]]; then
      mkdir -p -m 0755 ${D}
      chown ${C_USER}:${C_GROUP} ${D}
      MEC=$?
        case ${MEC} in
          [0]*)
# No problems
            :
          ;;
          *)
# Something happened - the directory structure could not be created.
# The program is being forced to exit.
# This might be a file permission problem.
            printf "Unable to create %s
Check your system and rerun script\n
Exiting ...\n" ${D}
            exit 3
          ;;
        esac
    fi
  done
# Clean out directory if not needed

## ************************************************************************** ##
# Delete the old Malware files
if [[ ${SIG_DB}/mbl.db ]]; then
  rm -f ${SIG_DB}/mbl.db
    if [[ ${MW_DIR}/mbl.db ]]; then
      rm -f ${MW_DIR}/mbl.db
    fi
fi
## ************************************************************************** ##
# See if we are to reload clamd after update
if [[ "${RELOAD}" -gt 0 ]]; then
# Check to see if the path to the PID file is set
  if [[ ${C_PID} ]]; then
# Now make sure that the file actually exists
    if [[ -s ${C_PID} ]]; then
      CLAMD_PID=$(cat ${C_PID})
    fi
# OK, the file doesn't exist so try to get the PID of the clamd program
  elif command -v pidof 2>/dev/null; then
    CLAMD_PID=$(pidof clamd)
  else
  # Maybe 'pidof' is not available. Try a more direct method
    if [[ $(ps -U ${C_USER} | awk '/clamd/ { print $1 }') ]]; then
      CLAMD_PID=$(ps -U ${C_USER} | awk '/clamd/ { print $1 }')
    else
    # OK, we cannot get the PID. Set $RELOAD to NO
      if [[ ! ${CLAMD_PID} ]]; then
        echo "Unable to get clamd PID. Turning 'RELOAD' off"
        RELOAD=0
      fi
    fi
  fi
fi
## ************************************************************************** ##
# Create the rsync file with the MSRBL files to download
# We delete any old version to insure that only the latest on is used.
if [[ -e ${MSR_DIR}/msrbl-files.txt ]]; then
  rm -f ${MSR_DIR}/msrbl-files.txt
fi
echo "MSRBL-Images.hdb" > ${MSR_DIR}/msrbl-files.txt
echo "MSRBL-SPAM-CR.ndb" >> ${MSR_DIR}/msrbl-files.txt
echo "MSRBL-SPAM.ndb" >> ${MSR_DIR}/msrbl-files.txt
chown ${C_USER}:${C_GROUP} ${MSR_DIR}/msrbl-files.txt
## ************************************************************************** ##
# Make sure we can find the program paths

# Make sure the required programs are present!
if command -v curl &>/dev/null; then
  DL_AGENT="curl"
  CMD=" -q -s -S --remote-name --location --remote-time"
elif command -v wget &>/dev/null; then
  DL_AGENT="wget"
  CMD=" -q -N "
else
  echo "Neither curl or wget can be found. Exiting program"
fi

# We will exit if one of the four named programs are not found.
for f in clamscan gunzip cmp rsync
do
  if ! command -v ${f} &>/dev/null; then
    printf "
\tCannot find: %s\n
\tWe have to exit\n" ${f}
    exit 6
  fi
done

# We assume 'rsync' has been found
RSY="rsync"

# Now check to make sure a version of 'gpg' is available
if [[ ${GET_SANE} -gt 0 ]]; then
  if command -v gpg2 &>/dev/null; then
    GPG_AGENT=$(command -v gpg2)
  elif command -v gpg &>/dev/null; then
    GPG_AGENT=$(command -v gpg)
  else
    printf "\n\tNeither gpg nor gpg2 not found
\tDisabling the downloading of Sanesecurity files.\n\n"
    GET_SANE=0
  fi
fi
## ************************************************************************** ##
# Set up GPG, if necessary
if [[ ${GET_SANE} -gt 0 ]]; then
  cd ${SANE_DB}
  if [ ! -s "${SANE_DB}/pubring.gpg" ]; then
    printf "\n\n
\tNo GPG keyring found; initialising
\t(This should only occur once)\n\n
\tPlease Stand By ***\n"
      case ${DL_AGENT} in
      [wget]*)
        if ! wget -O - "${gpg_key_url}" | ${GPG_AGENT} ${GPG_OPT} --import -
          then
           printf "\tERROR: could not import GPG public key; aborting\n"
          exit 7
        fi
      ;;
      [curl]*)
        if ! curl -q -s -S "${gpg_key_url}" | ${GPG_AGENT} ${GPG_OPT} --import -
          then
            printf "\tERROR: could not import GPG public key; aborting\n"
          exit 7
        fi
      ;;
      *)
        printf "\tNeither 'curl' nor 'wget' available. We are forced to exit\n"
        exit 6
      ;;
      esac
  fi
  chown ${C_USER}:${C_GROUP} "${SANE_DB}/pubring.gpg"
  chmod 0664 "${SANE_DB}/pubring.gpg"
# Remove the superfilous 'pubring.gpg~' file if it exists
  if [[ -e "${SANE_DB}/pubring.gpg~" ]]; then
    rm -f "${SANE_DB}/pubring.gpg~"
  fi
fi

## ************************************************************************** ##
##************************** FUNCTIONS ***************************************##
##****************************************************************************##
# This is the check_install function.
function check_install ()
{
# Clean the screen and switch to the tmp directory
cd ${T_DIR}

## Create an array of the files to be checked
LIMIT=0
for F in $(ls *.?db *.db *.ftm 2>/dev/null)
do
  if [[ -e ${F} ]]
    then
    DIRLIST[$LIMIT]=${F}
    LIMIT=$(( LIMIT+1 ))
  fi
done

## Initialize variables and start checking the files.
DIRLIST_COUNT=${#DIRLIST[*]}
FAILED=0
INSTALLED=0
LIMIT=0
NO_UPDATE=0

while [ "${LIMIT}" -lt "${DIRLIST_COUNT}" ]
do
clamscan --quiet --no-summary -d ${DIRLIST[$LIMIT]} </dev/null &>/dev/null
EC=$?
  case ${EC} in
  [0]*)
# Clamscan did not report any errors.
# Now check to see if this is a newer signature file.
# cmp will respond with '0' if the files are identical.
# 1 if they are different.
# 2 if the file does not exist.
# We will trap the exit code in variable 'CEC'.
# We are using the 's' flag to slightly improve speed.
# Remove them for more detailed output
# First make sure the file is larger than 0
    if [ -s ${DIRLIST[$LIMIT]} ]; then
      cmp -s ${DIRLIST[$LIMIT]} ${SIG_DB}/${DIRLIST[$LIMIT]}
      CEC=$?
    else
# The file has a 0 length -- bad
      CEC=9
    fi
  ;;
  *)
# Clamscan reported an error -- probably error 50.
# Therefore we will not attempt to install this file.
# The actual error code will be printed out in the event of a problem.
# The failed file will be erased.
# Comment out the line below beginning with 'rm' to save it.
# The variable $MVEC will be set to 'X' -- no-op
    printf "\n\a"
    printf "\t********** WARNING **********\n"
    printf "\tUnable to install: %s\n" ${DIRLIST[$LIMIT]}
    printf "\tClamscan exited with error code %d\n" ${EC}
    printf "\tTry downloading and installing the file again.\n\n"
    FAILED=$((FAILED+1))
    rm -f ${DIRLIST[$LIMIT]}
    MVEC="X"
    CEC=9
  ;;
  esac
# Process the cmp exit code
case ${CEC} in
  [0]*)
# The files are identical
# Update the 'NO_UPDATE' counter.
# Delete the file
# The variable $MVEC will be set to 'X' -- no-op
    if [[ ${W_SUM} -gt 0 ]]; then
      printf "\tNo update available %s\n" ${DIRLIST[$LIMIT]}
    fi
    NO_UPDATE=$((NO_UPDATE+1))
    rm -f ${DIRLIST[$LIMIT]}
    MVEC="X"
  ;;
  [1]*)
# The files are different
# We will install the file
# Trap the 'mv' exit code in 'MVEC'
    mv -f ${DIRLIST[$LIMIT]} ${SIG_DB}/${DIRLIST[$LIMIT]}
    MVEC=$?
  ;;
  [2]*)
# Error code 2 usually means that file(2) does not exist.
# We will attempt to install file(1).
# Trap the 'mv' exit code in 'MVEC'
    mv -f ${DIRLIST[$LIMIT]} ${SIG_DB}/${DIRLIST[$LIMIT]}
    MVEC=$?
  ;;
  [9]*)
# Bad news
# Something was wrong with the file. Probably 0 length
    :
  ;;
  *)
# cmp encountered a problem.
# We will not try to install the file.
# The file will be erased.
# The variable $MVEC will be set to 'X' -- no-op
# Incrementing the 'FAILED' counter
    printf "\tcmp issued error code %d\n" ${CEC}
    printf "\tUnable to update %s at this time\n" ${DIRLIST[$LIMIT]}
    printf "\tTry again later\n"
    MVEC="X"
    rm -f ${DIRLIST[$LIMIT]}
    FAILED=$((FAILED+1))
  ;;
esac
# Process the mv exit code
case ${MVEC} in
  [0]*)
# Everything went well. The file installed correctly.
# Increment the 'INSTALLED' counter.
    if [[ ${W_SUM} -gt 0 ]]; then
      printf "\tInstalled:......... %s\n" ${DIRLIST[$LIMIT]}
    fi
    INSTALLED=$((INSTALLED+1))
  ;;
  X*)
# Nothing happens here.
# For possible future use!
  :
  ;;
  *)
# OPPS, something went wrong.
# We are unable to install the file
# The file will be deleted
# Increment the 'FAILED' counter
    printf "\tmv issued error code %d\n" $MVEC
    printf "\tUnable to install at this time!\n"
    printf "\tPlease try again later\n"
      if [[ -n ${DIRLIST[$LIMIT]} ]]; then
        rm -f ${DIRLIST[$LIMIT]}
        FAILED=$((FAILED+1))
      fi
  ;;
esac
# Increment the 'LIMIT' counter.
LIMIT=$((LIMIT+1))
# Clear the 'MVEC' flag -- set to NULL
unset MVEC
done
}
##****************************************************************************##
# This is the get_files function.
function get_files ()
{
: << DELAY_DOWNLOAD
This is the "snooze" function. It will delay the start of a download session
between 0 and 546 seconds (Roughly 9 minutes). It will only work when the
script is run via CRON.
The variable $REST activates this function. 0=off & 1=on
DELAY_DOWNLOAD
# See if the variable 'REST' has been set or if forcing it from command line
if [[ ${REST} -gt 0 ]]
  then
# See if we are running via cron
    if [[ ! -t 0 ]]
      then
# Use the BASH RANDOM function to generate a random number between 0 & 32767
        RESTING=$((RANDOM/60))
        sleep ${RESTING}
    fi
fi

# We now download the MSRBL files using the the specified program.
case ${GET_MSRBL} in
  1)
  cd ${MSR_DIR}
  rsync -crtzq --files-from="${MSR_DIR}/msrbl-files.txt" ${MSRBL} ${MSR_DIR}
    for M in $(ls *.?db *.db 2>/dev/null); do
      chmod 0664 ${M}
      chown ${C_USER}:${C_GROUP} $M
      cp -pf ${M} ${T_DIR}
    done
  ;;
esac

case ${GET_SECURITE} in
 1)
  cd ${SI_DIR}
  for D in ${SI_URL}
    do
      FN=$(basename ${D})
        if [[ "${DL_AGENT}" == "curl" ]]; then
          curl ${CMD} -z "${FN}" $D
        elif [[ "${DL_AGENT}" == "wget" ]]; then
          wget ${CMD} ${D}
        else
        printf "\n\tWe don't seem to have a download agent.
\tSorry, but we have to exit\n"
        exit 6
        fi
    done

# Call the unzip function
  unzip ${SI_DIR}
  for SI in $(ls *.?db *.db 2>/dev/null); do
    chmod 0664 ${SI}
    chown ${C_USER}:${C_GROUP} ${SI}
    mv -f ${SI} ${T_DIR}
  done
  ;;
esac

case ${GET_MALWARE} in
 1)
# Get the Malware files
  cd ${MW_DIR}
  for D in ${MW_URL}
    do
      FN=${MW_FILE}
        if [[ "${DL_AGENT}" == "curl" ]]; then
          curl -q -L -s -S --output "${MW_DIR}/${MW_FILE}" -z "${MW_DIR}/${MW_FILE}" $D
        elif [[ "${DL_AGENT}" == "wget" ]]; then
          wget -q -O "${MW_DIR}/${MW_FILE}" ${MW_URL}
        else
          printf "\n\tWe don't seem to have a download agent.
\tSorry, but we have to exit\n"
        exit 6
        fi
    done

# Change file permission & ownership and copy to TMP directory.
for MW in $(ls *.ndb 2>/dev/null); do
  chmod 0664 ${MW}
  chown ${C_USER}:${C_GROUP} ${MW}
  cp -fp ${MW} ${T_DIR}
done
  ;;
esac

# SaneSecurity Files
case ${GET_SANE} in
  1)
  cd ${SANE_DB}
# Create a list of files to download from Sanesecurity
# Sanesecurity files
s_files="junk.ndb
junk.ndb.sig
jurlbl.ndb
jurlbl.ndb.sig
jurlbla.ndb
jurlbla.ndb.sig
lott.ndb
lott.ndb.sig
phish.ndb
phish.ndb.sig
rogue.hdb
rogue.hdb.sig
sanesecurity.ftm
sanesecurity.ftm.sig
scam.ndb
scam.ndb.sig
spamimg.hdb
spamimg.hdb.sig
spear.ndb
spear.ndb.sig"
;;
esac

# Winnow files
if [[ ${GET_WINNOW} -eq 1 ]]; then
  case ${WPC} in
    1)
      w_files="winnow_malware.hdb
winnow_malware.hdb.sig
winnow_malware_links.ndb
winnow_malware_links.ndb.sig
winnow_phish_complete_url.ndb
winnow_phish_complete_url.ndb.sig"
    ;;
    2)
      w_files="winnow_phish_complete.ndb
winnow_phish_complete.ndb.sig
winnow_spam_complete.ndb
winnow_spam_complete.ndb.sig"
    ;;
    3)
    w_files="winnow_malware.hdb
winnow_malware.hdb.sig
winnow_malware_links.ndb
winnow_malware_links.ndb.sig
winnow_phish_complete.ndb
winnow_phish_complete.ndb.sig
winnow_phish_complete_url.ndb
winnow_phish_complete_url.ndb.sig
winnow_spam_complete.ndb
winnow_spam_complete.ndb.sig"
    ;;
  esac
fi

# ldb files
ldb_files="spam.ldb
spam.ldb.sig"

if [[ ${SANE_DB}/sane_include.txt ]]; then
  rm -f ${SANE_DB}/sane_include.txt
  touch ${SANE_DB}/sane_include.txt
  chown ${C_USER}:${C_GROUP} ${SANE_DB}/sane_include.txt
  chmod 0664 ${SANE_DB}/sane_include.txt
fi
# if downloading sane files not disabled
if [[ ${GET_SANE} -eq 1 ]]; then
  printf "%s\n" ${s_files} >> ${SANE_DB}/sane_include.txt
fi
# if winnow files not disabled
if [[ ${GET_WINNOW} -gt 0 && ${GET_SANE} -eq 1 ]]; then
  printf "%s\n" ${w_files} >> ${SANE_DB}/sane_include.txt
fi
# if ldb file not disabled
if [[ ${GET_LDB} -eq 1 && ${GET_SANE} -eq 1 ]]; then
  printf "%s\n" ${ldb_files} >> ${SANE_DB}/sane_include.txt
fi

XOPS="--files-from=${SANE_DB}/sane_include.txt"
rsync -crtzq ${XOPS} ${SANE} ${SANE_DB} 2>/dev/null
# Change the file ownership and mode
  for C in $(ls *.sig *.?db *.ftm 2>/dev/null); do
    chmod 0664 ${C}
    chown ${C_USER}:${C_GROUP} ${C}
  done
  # Check the signature - discard if bad
  for F in $(ls *.?db *.ftm 2>/dev/null)
    do
      if ! gpg_out=$(${GPG_AGENT} ${GPG_OPT} --verify "${F}.sig" "${F}" 2>&1); then
        echo "Security Error ${F} is missing gpg sig" >&2
        echo "${gpg_out}" >&2
        rm -f "${F}.sig" "${F}"
      else
        cp -pf ${F} ${T_DIR}
      fi
    done
}
##****************************************************************************##
# This is the unzip function
function unzip ()
{
# Change to the correct directory
cd ${1}
# Change file permission's and ownership
for ZF in $(ls *.gz 2>/dev/null); do
  chown ${C_USER}:${C_GROUP} ${ZF}
  chmod 0664 ${ZF}
done

# Get a listing of the *.gz files
ZIPFILES=( $(ls *.gz 2>/dev/null) )

# Set variables
LIMIT=0
ZIPFILES_COUNT=${#ZIPFILES[*]}

while [ ${LIMIT} -lt ${ZIPFILES_COUNT} ]; do
# Get the files name and strip the '.gz' extension
  NoGZ=${ZIPFILES[$LIMIT]/%.gz/}
# Save the original gunzip file and its unzipped version
  gunzip -qfN <${ZIPFILES[$LIMIT]}> ${NoGZ}
# Capture the exit code
  GZEC=$?
    case ${GZEC} in
      [0]*)
# No problems.
      :
      ;;
      [1]*)
# Gunzip has a problem.
# Check the error code and try again!
      printf "\tgunzip issued error code %d\n" ${GZEC}
      printf "\tUnable to gunzip %s\n" ${ZIPFILES[$LIMIT]}
      printf "\tPlease try again later\n"
      ;;
      [2]*)
# Gunzip issued a warning. We will attempt to continue.
      printf "\tgunzip issued warning code %d\n" ${GZEC}
      printf "\tWe will attempt to continue\n"
      ;;
    esac
  LIMIT=$((LIMIT+1))
done
}
##****************************************************************************##
# This is the reload function
function reload_db ()
{
# See if any files were installed
if [[ ${INSTALLED} -gt 0 ]]; then
  if [[ "${RELOAD}" -gt 0 ]]; then
# Check if clamd is running
    if [[ -z "${CLAMD_PID}" ]]; then
# CLAM_PID not set
      printf "\tCLAM_PID not set. Unable to restart clamd.\n"
    else
      kill -USR2 ${CLAMD_PID}
        if [[ ${W_SUM} -gt 0 ]]; then
          printf "\tDatabase Reloaded\n"
        fi
    fi
  fi
fi
}
## ***************************************************************************##
function summary ()
{
# See if we are to print out a summary
if [[ ${W_SUM} -gt 0 ]]; then
# If a file has been installed, start here.
  if [[ ${INSTALLED} -gt 0 ]]; then
    printf "\n\tFiles saved to: %s\n\n" ${SIG_DB}
    printf "\tInstalled:   %d\n" ${INSTALLED}
    printf "\tNot Updated: %d\n" ${NO_UPDATE}
    printf "\tFailed:      %d\n\n" ${FAILED}
  else
# If a new file has not been installed, we branch here.
    INSTALLED=0
    printf "\n\tReloading of the database not required.\n\n"
    printf "\tInstalled:   %d\n" ${INSTALLED}
    printf "\tNot Updated: %d\n" ${NO_UPDATE}
    printf "\tFailed:      %d\n\n" ${FAILED}
  fi
fi
}

## ************************************************************************** ##
function log ()
{
if [[ ${MK_LOG} -gt 0 ]]; then
  local LOG_FILE_DATE=$(date "+%y-%m")
  local LOG_FILE_SUFFIX=".log"
  local LOG_NAME="scamp"
  local LOG_PATH="/var/log/"
  local D_FORMAT=$(date "+%B %d %T scamp:")
    if [[ ${L_TYPE} -eq 1 ]]; then
      local LOG_FILE="${LOG_PATH}${LOG_NAME}-${LOG_FILE_DATE}${LOG_FILE_SUFFIX}"
    else
      local LOG_FILE="${LOG_PATH}${LOG_NAME}${LOG_FILE_SUFFIX}"
    fi

    if [[ ! -s ${LOG_FILE} ]]; then
      touch ${LOG_FILE}
      chown ${C_USER}:${C_GROUP} ${LOG_FILE}
      chmod 0644 ${LOG_FILE}
    fi
    printf "${D_FORMAT} Updated %d.  Not Updated %d.  Failed %d.\n" ${INSTALLED} ${NO_UPDATE} ${FAILED} >> ${LOG_FILE}
fi
}
## ***************************************************************************##
# Syslog function

function log_syslog ()
{
local LOG_FILE="${T_DIR}/$(date "+%s")"
local D_FORMAT=$(date "+%B %d %T")
local TAG="-t scamp"
printf "Updated %d.  Not Updated %d.  Failed %d.\n" ${INSTALLED} ${NO_UPDATE} ${FAILED} > ${LOG_FILE}
logger -i ${TAG} -f "${LOG_FILE}"
rm -f ${LOG_FILE}
}
## ***************************************************************************##
function clean_up_tmp ()
{
# Remove any files that don't belong in tmp
cd ${T_DIR}
for F in $(ls *.?db *.db *.ftm *.gz 2>/dev/null)
  do
    rm -f ${F}
  done
}
##                           Start Program                                    ##
clean_up_tmp
get_files
check_install
summary
reload_db
log
if [[ ${SYS_LOG} -eq 1 ]]; then
  log_syslog
fi
clean_up_tmp
exit 0
: << IMPORTANT
Good luck! Read the "README" file for the script documentation!

Any questions, suggestions, patches, etc. should be directed to me. I
really would appreciate it. To make tracking of 'bug' reports easier, please
do the following:

1) Go to: https://sourceforge.net/projects/scamp/
2) Click on "TRACKER"
3) Click on "Bug Reports"
4) Click on "Add New"
5) Fill out the report with complete information including the version of
   the script you are using, your OS and version of bash, rsync, gpg/gpg2,
   curl and/or wget and your version of Clamav. If possible, include the
   complete text of any error messages, etc.
IMPORTANT
